package com.yunfeiyun.agmp.fms.service.impl;

import com.yunfeiyun.agmp.fms.domain.FmsCrop;
import com.yunfeiyun.agmp.fms.domain.FmsTaskpick;
import com.yunfeiyun.agmp.fms.mapper.FmsTaskpickMapper;
import com.yunfeiyun.agmp.fms.domain.reqvo.FmsPlanReqVo;
import com.yunfeiyun.agmp.fms.domain.reqvo.FmsTaskPickListReqVo;
import com.yunfeiyun.agmp.fms.domain.reqvo.FmsTaskPickStockDetailReqVo;
import com.yunfeiyun.agmp.fms.domain.resvo.FmsTaskPickListResVo;
import com.yunfeiyun.agmp.fms.domain.resvo.FmsTaskPickStockDetailResVo;
import com.yunfeiyun.agmp.fms.domain.resvo.FmsTaskPickStockListResVo;
import com.yunfeiyun.agmp.fms.service.IFmsTaskpickService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 农事任务采收Service业务层处理
 * 
 * @author 杨晓辉
 * @date 2023-05-23
 */
@Service
public class FmsTaskpickServiceImpl implements IFmsTaskpickService 
{
    @Autowired
    private FmsTaskpickMapper fmsTaskpickMapper;

    /**
     * 查询农事任务采收
     * 
     * @param taskpickId 农事任务采收主键
     * @return 农事任务采收
     */
    @Override
    public FmsTaskpick selectFmsTaskpickByTaskpickId(String taskpickId)
    {
        return fmsTaskpickMapper.selectFmsTaskpickByTaskpickId(taskpickId);
    }

    /**
     * 查询农事任务采收列表
     * 
     * @param fmsTaskPickListReqVo 农事任务采收
     * @return 农事任务采收
     */
    @Override
    public List<FmsTaskPickListResVo> selectFmsTaskpickList(FmsTaskPickListReqVo fmsTaskPickListReqVo)
    {
        return fmsTaskpickMapper.selectFmsTaskpickList(fmsTaskPickListReqVo);
    }

    /**
     * 查询农事任务采收农产品列表
     * @param fmsTaskPickStockListReqVo 农事任务采收农产品列表参数
     * @return 农事任务采收农产品列表
     **/
    @Override
    public List<FmsTaskPickStockListResVo> selectFmsTaskPickStockList(FmsCrop fmsCrop) {
        return fmsTaskpickMapper.selectFmsTaskPickStockList(fmsCrop);
    }

    @Override
    public List<FmsTaskPickStockListResVo> selectFmsTaskPickStockListStat(FmsTaskPickListReqVo reqVo) {
        return fmsTaskpickMapper.selectFmsTaskPickStockListStat(reqVo);
    }

    @Override
    public List<FmsTaskPickStockListResVo> selectSumPickWeightListGroupByCropName(FmsPlanReqVo reqVo) {
        return fmsTaskpickMapper.selectSumPickWeightListGroupByCropName(reqVo);
    }

    /**
     * 查询农事任务采收农产品详情
     * @param fmsTaskPickStockDetailReqVo 农事任务采收农产品详情参数
     * @return 农事任务采收农产品详情列表
     **/
    @Override
    public List<FmsTaskPickStockDetailResVo> selectFmsTaskPickStockDetailList(FmsTaskPickStockDetailReqVo fmsTaskPickStockDetailReqVo) {
        return fmsTaskpickMapper.selectFmsTaskPickStockDetailList(fmsTaskPickStockDetailReqVo);
    }

    @Override
    public List<FmsTaskPickListResVo> selectFmsTaskpickByPlanId(String planId) {
        return fmsTaskpickMapper.selectFmsTaskpickByPlanId(planId);
    }

    /**
     * 新增农事任务采收
     * 
     * @param fmsTaskpick 农事任务采收
     * @return 结果
     */
    @Override
    public int insertFmsTaskpick(FmsTaskpick fmsTaskpick)
    {
        return fmsTaskpickMapper.insertFmsTaskpick(fmsTaskpick);
    }

    /**
     * 修改农事任务采收
     * 
     * @param fmsTaskpick 农事任务采收
     * @return 结果
     */
    @Override
    public int updateFmsTaskpick(FmsTaskpick fmsTaskpick)
    {
        return fmsTaskpickMapper.updateFmsTaskpick(fmsTaskpick);
    }

    /**
     * 批量删除农事任务采收
     * 
     * @param taskpickIds 需要删除的农事任务采收主键
     * @return 结果
     */
    @Override
    public int deleteFmsTaskpickByTaskpickIds(String[] taskpickIds)
    {
        return fmsTaskpickMapper.deleteFmsTaskpickByTaskpickIds(taskpickIds);
    }

    /**
     * 删除农事任务采收信息
     * 
     * @param taskpickId 农事任务采收主键
     * @return 结果
     */
    @Override
    public int deleteFmsTaskpickByTaskpickId(String taskpickId)
    {
        return fmsTaskpickMapper.deleteFmsTaskpickByTaskpickId(taskpickId);
    }
}
